@@ -1,9 +1,10 @@
 package BenchmarkAnything::Storage::Backend::SQL;
-BEGIN {
-  $BenchmarkAnything::Storage::Backend::SQL::AUTHORITY = 'cpan:TAPPER';
-}
+# git description: v0.015-8-gf5dd98c
+
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Autonomous SQL backend to store benchmarks
-$BenchmarkAnything::Storage::Backend::SQL::VERSION = '0.015';
+$BenchmarkAnything::Storage::Backend::SQL::VERSION = '0.016';
+use 5.008;
 use strict;
 use warnings;
 
@@ -499,6 +500,34 @@ sub list_benchmark_names {
 
 }
 
+sub list_additional_keys {
+
+    my ( $or_self, $s_pattern ) = @_;
+
+    my $ar_pattern = defined($s_pattern) ? [$s_pattern] : [];
+
+    my $s_key;
+    if ( $or_self->{cache} ) {
+        require JSON::XS;
+        $s_key = JSON::XS::encode_json($ar_pattern);
+        if ( my $ar_search_data = $or_self->{cache}->get("list_additional_keys||$s_key") ) {
+            return $ar_search_data;
+        }
+    }
+
+    my $ar_result = $or_self->{query}
+        ->select_additional_keys( @$ar_pattern )
+        ->fetchall_arrayref([0]);
+    my $ar_key_names = [ map { $_->[0] } @$ar_result ];
+
+    if ( $or_self->{cache} ) {
+        $or_self->{cache}->set( "list_additional_keys||$s_key" => $ar_key_names );
+    }
+
+    return $ar_key_names;
+
+}
+
 sub get_single_benchmark_point {
 
     my ( $or_self, $i_bench_value_id ) = @_;
@@ -726,13 +755,37 @@ sub subsume {
 
 }
 
+sub _get_additional_key_id {
+
+    my ( $or_self, $s_key ) = @_;
+
+    return $or_self->{query}->select_additional_key_id($s_key)->fetch->[0];
+
+}
+
+sub default_columns {
+
+    my ( $or_self ) = @_;
+
+    return $or_self->{query}->default_columns;
+
+}
+
+sub benchmark_operators {
+
+    my ( $or_self ) = @_;
+
+    return $or_self->{query}->benchmark_operators;
+
+}
+
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -1181,6 +1234,13 @@ Get a list of all benchmark NAMEs, optionally matching a given pattern
 
  $benchmarkanythingdata = $or_bench->list_benchmark_names($pattern);
 
+=head3 list_additional_keys
+
+Get a list of all additional key names, optionally matching a given
+pattern (SQL LIKE syntax, i.e., using C<%> as placeholder.
+
+ $benchmarkanythingdata = $or_bench->list_additional_keys($pattern);
+
 =head3 enqueue_multi_benchmark
 
 As a low-latency alternative to directly calling
@@ -1314,13 +1374,26 @@ In case of a true value the module cache some select results
 
 =back
 
+=head3 default_columns
+
+Returns the hash about those columns that are by default part of each
+single data point (NAME, UNIT, VALU, VALUE_ID, CREATED, each with its
+internal column name). These default columns might go away in the
+future, but for now some systems need this internal information.
+
+=head3 benchmark_operators
+
+Returns the list of operators supported by the query language. This is
+provided for frontend systems that support creating queries
+automatically.
+
 =head1 AUTHOR
 
 Roberto Schaefer <schaefr@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Amazon.com, Inc. or its affiliates.
+This software is Copyright (c) 2016 by Amazon.com, Inc. or its affiliates.
 
 This is free software, licensed under:
 
