@@ -1,9 +1,7 @@
 package BenchmarkAnything::Storage::Backend::SQL::Query;
-BEGIN {
-  $BenchmarkAnything::Storage::Backend::SQL::Query::AUTHORITY = 'cpan:TAPPER';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: BenchmarkAnything::Storage::Backend::SQL - querying - base class
-$BenchmarkAnything::Storage::Backend::SQL::Query::VERSION = '0.015';
+$BenchmarkAnything::Storage::Backend::SQL::Query::VERSION = '0.016';
 use strict;
 use warnings;
 use Digest::MD5;
@@ -118,7 +116,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -130,7 +128,7 @@ Roberto Schaefer <schaefr@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Amazon.com, Inc. or its affiliates.
+This software is Copyright (c) 2016 by Amazon.com, Inc. or its affiliates.
 
 This is free software, licensed under:
 
