@@ -1,9 +1,7 @@
 package BenchmarkAnything::Storage::Backend::SQL::Query::common;
-BEGIN {
-  $BenchmarkAnything::Storage::Backend::SQL::Query::common::AUTHORITY = 'cpan:TAPPER';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: BenchmarkAnything::Storage::Backend::SQL - querying - backend base class
-$BenchmarkAnything::Storage::Backend::SQL::Query::common::VERSION = '0.015';
+$BenchmarkAnything::Storage::Backend::SQL::Query::common::VERSION = '0.016';
 use strict;
 use warnings;
 use base 'BenchmarkAnything::Storage::Backend::SQL::Query';
@@ -350,6 +348,31 @@ sub select_benchmark_names {
 
 }
 
+sub select_additional_keys {
+
+    my ( $or_self, @a_vals ) = @_;
+
+    my $query = "
+        SELECT DISTINCT bench_additional_type
+        FROM $or_self->{config}{tables}{additional_type_table}";
+    $query .= "
+        WHERE bench_additional_type LIKE ? " if @a_vals;
+    return $or_self->execute_query( $query, @a_vals );
+
+}
+
+sub select_additional_key_id {
+
+    my ( $or_self, @a_vals ) = @_;
+
+    return $or_self->execute_query( "
+        SELECT DISTINCT bench_additional_type_id
+        FROM $or_self->{config}{tables}{additional_type_table}
+        WHERE bench_additional_type = ?
+    ", @a_vals );
+
+}
+
 sub select_unit {
 
     my ( $or_self, @a_vals ) = @_;
@@ -381,7 +404,7 @@ sub select_addvalue {
     return $or_self->execute_query( "
         SELECT bench_additional_value_id
         FROM $or_self->{config}{tables}{additional_value_table}
-        WHERE bench_additional_type_id = ? AND bench_additional_value = ?
+        WHERE bench_additional_type_id = ? AND bench_additional_value ".(defined($a_vals[1]) ? '= ?' : 'IS NULL')."
     ", @a_vals );
 
 }
@@ -594,7 +617,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -606,7 +629,7 @@ Roberto Schaefer <schaefr@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Amazon.com, Inc. or its affiliates.
+This software is Copyright (c) 2016 by Amazon.com, Inc. or its affiliates.
 
 This is free software, licensed under:
 
